backwardTarget property
Called at gesture-start to pick the route the user should land on
after a backward (left-to-right) drag completes. Return null to
disable backward drags.
Implementation
final RouteState? Function() backwardTarget;
Called at gesture-start to pick the route the user should land on
after a backward (left-to-right) drag completes. Return null to
disable backward drags.
final RouteState? Function() backwardTarget;