forwardTarget property
Called at gesture-start to pick the route the user should land on
after a forward (right-to-left) drag completes. Return null to
disable forward drags from here.
Implementation
final RouteState? Function() forwardTarget;
Called at gesture-start to pick the route the user should land on
after a forward (right-to-left) drag completes. Return null to
disable forward drags from here.
final RouteState? Function() forwardTarget;